Adds two-sided Wald p-values to the coefficient table of a model fitted with MASS::polr().

ordinal_p(mdl)

Arguments

mdl

A fitted polr model.

Value

A coefficient matrix with an additional p value column.

Examples

if (FALSE) { # \dontrun{
model <- MASS::polr(Sat ~ Infl + Type + Cont, MASS::housing, Hess = TRUE)
ordinal_p(model)
} # }