Runs pairwise Wilcoxon tests for all columns whose names begin with PredictedSize. and returns the cell-wise mean adjusted p-values.

pairwise_wilcox(predictor, data, method = "holm", x = 6)

Arguments

predictor

Name of the categorical grouping variable.

data

Data frame containing the grouping and prediction columns.

method

P-value adjustment method passed to stats::pairwise.wilcox.test().

x

Number of decimal places used to round the result.

Value

A matrix of averaged adjusted p-values.