Fits one Gaussian mixed-effects model for each fixed-effect term, omitting that term in turn, and reports marginal and conditional R-squared values.

predictor_strength(dependent, fixed, random_str, data)

Arguments

dependent

Name of the dependent variable.

fixed

Character vector of fixed-effect terms.

random_str

Character vector defining the random-effect structure.

data

Data frame used to fit the models.

Value

A data frame with the omitted predictor and the model's marginal and conditional R-squared values.

Examples

if (FALSE) { # \dontrun{
data("data_s")
predictor_strength(
  dependent = "sDur",
  fixed = c("pauseBin", "list", "folType", "baseDur"),
  random_str = c("(1 | speaker)", "(1 | item)"),
  data = data_s
)
} # }