| se | R Documentation |
Compute the standard error of a numerical or ordinal variable.
se(x)
x |
A numeric vector containing the values whose stadard error is to be computed. |
D. Schmitz
data("data_s")
se(data = data_s$age)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.