R/mode_stat.R
mode_stat.Rd
Returns the first value with the greatest observed frequency.
mode_stat(x, na.rm = FALSE)
A vector.
Remove missing values before computing the mode.
A length-one vector of the same basic type as x.
x
mode_stat(c(1, 1, 2, 3)) #> [1] 1