mode_stat: Mode (Statistical)

View source: R/mode_stat.R

mode_statR Documentation

Mode (Statistical)

Description

Compute the mode of a numerical or ordinal variable.

Usage

mode_stat(x)

Arguments

x

A numeric vector containing the values whose mode is to be computed.

Author(s)

D. Schmitz

Examples

data("data_s")

mode_stat(x = data_s$age)


dosc91/SfL documentation built on Sept. 14, 2024, 6:44 a.m.