| mode_stat | R Documentation |
Compute the mode of a numerical or ordinal variable.
mode_stat(x)
x |
A numeric vector containing the values whose mode is to be computed. |
D. Schmitz
data("data_s")
mode_stat(x = data_s$age)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.