R/ordinal_p.R
ordinal_p.Rd
Adds two-sided Wald p-values to the coefficient table of a model fitted with MASS::polr().
MASS::polr()
ordinal_p(mdl)
A fitted polr model.
polr
A coefficient matrix with an additional p value column.
p value
if (FALSE) { # \dontrun{ model <- MASS::polr(Sat ~ Infl + Type + Cont, MASS::housing, Hess = TRUE) ordinal_p(model) } # }