Runs pairwise Wilcoxon tests for all columns whose names begin with
PredictedSize. and returns the cell-wise mean adjusted p-values.
pairwise_wilcox(predictor, data, method = "holm", x = 6)Name of the categorical grouping variable.
Data frame containing the grouping and prediction columns.
P-value adjustment method passed to
stats::pairwise.wilcox.test().
Number of decimal places used to round the result.
A matrix of averaged adjusted p-values.